@@ -5,12 +5,53 @@
     created by FAST-DEV 2021/4/6
 """
 import json
+import requests
 import socket
 from fast_tracker import config
-from fast_tracker.client import TraceSegmentReportService
+from fast_tracker.loggings import logger
+from fast_tracker.client import ServiceManagementClient, TraceSegmentReportService
 from fast_tracker.report.report_struct import ReportStruct
+from fast_tracker.trace import tags
 from fast_tracker.utils import functions
 
+
+class UdpServiceManagementClient(ServiceManagementClient):
+    def __init__(self):
+        self.session = requests.session()
+
+    def send_instance_props(self):
+        url = config.collector_address.rstrip("/") + "/v3/management/reportProperties"
+        res = self.session.post(
+            url,
+            json={
+                "service": config.service_name,
+                "serviceInstance": config.service_instance,
+                "properties": [
+                    {
+                        "language": "Python",
+                    }
+                ],
+            },
+        )
+        logger.debug("heartbeat response: %s", res)
+
+    def send_heart_beat(self):
+        logger.debug(
+            "service heart beats, [%s], [%s]",
+            config.service_name,
+            config.service_instance,
+        )
+        url = config.collector_address.rstrip("/") + "/v3/management/keepAlive"
+        res = self.session.post(
+            url,
+            json={
+                "service": config.service_name,
+                "serviceInstance": config.service_instance,
+            },
+        )
+        logger.debug("heartbeat response: %s", res)
+
+
 class UdpTraceSegmentReportService(TraceSegmentReportService):
     def __init__(self):
         self.udp_ip = ""
@@ -65,6 +106,7 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
                     data = self._get_data(segment, span)
                     functions.log("udp socket object get data", level=4)
                     res = udp_sock.sendto(data, (self.udp_ip, self.udp_port))
+                    # res = udp_sock.sendto(data, ("fluent-bit", 5140))
                     functions.log("udp socket ip: %s, port: %d", self.udp_ip, self.udp_port, level=4)
                     functions.log("sended message: %r, result is: %r", data, res)
         except BaseException as e:
@@ -112,7 +154,10 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
         if not tags_data:
             return data
         for tag in tags_data:
-            data[tag.key] = tag.val
+            if tag.key == tags.HttpStatus:
+                data[tag.key] = str(tag.val)
+            else:
+                data[tag.key] = tag.val
 
         return data
 
