@@ -92,7 +92,7 @@ class SpanContext(object):
         parent_id = ""
         if parent:
             parent_id = parent.sid
-        elif carrier.span_id:
+        elif carrier.span_id:  # 当跨服务调用的时候，carrier.span_id等都有值，span_id为上一个服务调用此服务的span_id
             parent_id = carrier.span_id
 
         span = (
